@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define FILTERACTIONMISSINGACCOUNTDIALOG_H
 
 #include <QDialog>
-namespace MailCommon {
+namespace MailCommon
+{
 class KMFilterAccountList;
 class FilterActionMissingAccountDialog : public QDialog
 {
