@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 #include <QDialog>
 class QUrl;
 
-namespace MailCommon {
+namespace MailCommon
+{
 class SelectThunderbirdFilterFilesWidget;
 class SelectThunderbirdFilterFilesDialog : public QDialog
 {
