@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef INVALIDFILTERINFOWIDGET_H
 #define INVALIDFILTERINFOWIDGET_H
 
-#include <KMessageWidget>
 #include "mailcommon_private_export.h"
-namespace MailCommon {
+#include <KMessageWidget>
+namespace MailCommon
+{
 class MAILCOMMON_TESTS_EXPORT InvalidFilterInfoWidget : public KMessageWidget
 {
     Q_OBJECT
