@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,11 +16,12 @@ using MessageCore::MailingList;
 #include <Collection>
 #include <CollectionStatistics>
 
+#include <KIO/Job>
 #include <KSharedConfig>
 #include <QKeySequence>
-#include <KIO/Job>
 
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * @brief The FolderSettings class
  * @author Laurent Montel <montel@kde.org>
@@ -30,10 +31,9 @@ class MAILCOMMON_EXPORT FolderSettings : public QObject
     Q_OBJECT
 
 public:
-    static QSharedPointer<FolderSettings> forCollection(
-        const Akonadi::Collection &coll, bool writeConfig = true);
+    static QSharedPointer<FolderSettings> forCollection(const Akonadi::Collection &coll, bool writeConfig = true);
 
-    ~FolderSettings();
+    ~FolderSettings() override;
 
     void setCollection(const Akonadi::Collection &collection);
 
