@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class SnippetCustomFileAttachmentNameDialogTest : public QObject
     Q_OBJECT
 public:
     explicit SnippetCustomFileAttachmentNameDialogTest(QObject *parent = nullptr);
-    ~SnippetCustomFileAttachmentNameDialogTest() = default;
+    ~SnippetCustomFileAttachmentNameDialogTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
