@@ -2,7 +2,7 @@
   snippet feature from kdevelop/plugins/snippet/
 
   SPDX-FileCopyrightText: 2007 Robert Gruber <rgruber@users.sourceforge.net>
-  SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,7 +18,8 @@ class QAbstractItemModel;
 class QModelIndex;
 class QPushButton;
 
-namespace MailCommon {
+namespace MailCommon
+{
 class SnippetWidget;
 class SnippetDialog : public QDialog
 {
@@ -26,7 +27,7 @@ class SnippetDialog : public QDialog
 
 public:
     explicit SnippetDialog(KActionCollection *actionCollection, bool inGroupMode, QWidget *parent = nullptr);
-    ~SnippetDialog();
+    ~SnippetDialog() override;
 
     void setName(const QString &name);
     Q_REQUIRED_RESULT QString name() const;
